package dev.fitko.fitconnect.api.domain.model.event;

import dev.fitko.fitconnect.api.domain.model.event.problems.Problem;
import dev.fitko.fitconnect.api.domain.model.submission.Submission;
import dev.fitko.fitconnect.api.domain.model.submission.SubmissionForPickup;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@Data
@Builder
@AllArgsConstructor
public class EventPayload {

    private UUID submissionId;
    private UUID destinationId;
    private UUID caseId;

    // used for auth-tag validation
    private String encryptedMetadata;
    private String encryptedData;
    private Map<UUID, String> encryptedAttachments;

    private List<Problem> problems;

    public static EventPayload forRejectEvent(final SubmissionForPickup submission, final List<Problem> problems) {
        return EventPayload.builder()
                .submissionId(submission.getSubmissionId())
                .destinationId(submission.getDestinationId())
                .caseId(submission.getCaseId())
                .problems(problems)
                .build();
    }

    public static EventPayload forRejectEvent(final Submission submission, final List<Problem> problems) {
        return EventPayload.builder()
                .submissionId(submission.getSubmissionId())
                .destinationId(submission.getDestinationId())
                .caseId(submission.getCaseId())
                .problems(problems)
                .build();
    }

    public static EventPayload forAcceptEvent(final Submission submission, final Problem... problems) {
        return EventPayload.builder()
                .submissionId(submission.getSubmissionId())
                .destinationId(submission.getDestinationId())
                .caseId(submission.getCaseId())
                .encryptedData(submission.getEncryptedData())
                .encryptedMetadata(submission.getEncryptedMetadata())
                .encryptedAttachments(Collections.emptyMap())
                .problems(Arrays.asList(problems))
                .build();
    }

    public static EventPayload forAcceptEventWithAttachments(final Submission submission, final Map<UUID, String> encryptedAttachments, final Problem... problems) {
        return EventPayload.builder()
                .submissionId(submission.getSubmissionId())
                .destinationId(submission.getDestinationId())
                .caseId(submission.getCaseId())
                .encryptedData(submission.getEncryptedData())
                .encryptedMetadata(submission.getEncryptedMetadata())
                .encryptedAttachments(encryptedAttachments)
                .problems(Arrays.asList(problems))
                .build();
    }

}
