package dev.fitko.fitconnect.api.domain.model.metadata.payment;

import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.NonNull;

import java.net.URI;
import java.util.Date;

@Data
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
public class PaymentInformation {

    private URI transactionUrl;
    private String transactionId;
    private String transactionReference;
    private Date transactionTimestamp;
    private PaymentMethod paymentMethod;
    private String paymentMethodDetail;
    private PaymentStatus status;
    private double grossAmount;

    public static Builder builder() {
        return new Builder();
    }

    public static class Builder {
        private URI transactionUrl;
        private @NonNull String transactionId;
        private @NonNull String transactionReference;
        private @NonNull Date transactionTimestamp;
        private @NonNull PaymentMethod paymentMethod;
        private String paymentMethodDetail;
        private @NonNull PaymentStatus status;
        private double grossAmount;

        public Builder withTransactionUrl(final URI transactionUrl) {
            this.transactionUrl = transactionUrl;
            return this;
        }

        public Builder withTransactionId(final String transactionId) {
            this.transactionId = transactionId;
            return this;
        }

        public Builder withTransactionReference(final String transactionReference) {
            this.transactionReference = transactionReference;
            return this;
        }

        public Builder withTransactionTimestamp(final Date transactionTimestamp) {
            this.transactionTimestamp = transactionTimestamp;
            return this;
        }

        public Builder withPaymentMethod(final PaymentMethod paymentMethod) {
            this.paymentMethod = paymentMethod;
            return this;
        }

        public Builder withPaymentMethodDetail(final String paymentMethodDetail) {
            this.paymentMethodDetail = paymentMethodDetail;
            return this;
        }

        public Builder withStatus(final PaymentStatus status) {
            this.status = status;
            return this;
        }

        public Builder withGrossAmount(final double grossAmount) {
            this.grossAmount = grossAmount;
            return this;
        }

        public PaymentInformation build() {
            return new PaymentInformation(transactionUrl, transactionId, transactionReference, transactionTimestamp, paymentMethod, paymentMethodDetail, status, grossAmount);
        }
    }
}
