package dev.fitko.fitconnect.client.util;

import com.nimbusds.jose.jwk.JWK;
import com.nimbusds.jose.jwk.KeyOperation;
import dev.fitko.fitconnect.api.domain.crypto.JWKPair;
import dev.fitko.fitconnect.api.domain.model.reply.replychannel.EncryptionPublicKey;
import org.junit.jupiter.api.Test;

import java.util.stream.Collectors;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

public class EncryptionKeyMapperTest {

    @Test
    void testKeyMapping(){

        // Given
        final JWKPair jwkPair = ReplyChannelKeyGenerator.generateKeyPair();
        final JWK publicKey = jwkPair.getPublicKey();

        final var expectedEncryptionKey = new EncryptionPublicKey();
        expectedEncryptionKey.setKid(publicKey.getKeyID());
        expectedEncryptionKey.setKty(publicKey.getKeyType().getValue());
        expectedEncryptionKey.setAlg(publicKey.getAlgorithm().getName());
        expectedEncryptionKey.setN(publicKey.toRSAKey().getModulus().toString());
        expectedEncryptionKey.setE(publicKey.toRSAKey().getPublicExponent().toString());
        expectedEncryptionKey.setKeyOps(publicKey.getKeyOperations().stream().map(KeyOperation::identifier).collect(Collectors.toList()));

        // When
        final EncryptionPublicKey encryptionPublicKey = EncryptionPublicKey.fromJwk(publicKey);

        // Then
        assertThat(encryptionPublicKey, is(expectedEncryptionKey));

    }
}
