package dev.fitko.fitconnect.core;

import com.github.tomakehurst.wiremock.WireMockServer;
import com.github.tomakehurst.wiremock.client.WireMock;
import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.config.Environment;
import dev.fitko.fitconnect.api.config.EnvironmentName;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;

import java.util.List;
import java.util.Map;

import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.wireMockConfig;

public abstract class RestEndpointBase {

    public static WireMockServer wireMockServer = new WireMockServer(wireMockConfig().dynamicPort());

    @BeforeEach
    public void startWireMock() {
        wireMockServer.start();
        WireMock.configureFor("localhost", wireMockServer.port());
    }

    @AfterEach
    public void shutDownWireMock() {
        wireMockServer.stop();
    }

    protected ApplicationConfig getTestConfig(final String fakeBaseUrl) {

        final var envName = new EnvironmentName("TESTING");
        final var environments = Map.of(envName, new Environment(fakeBaseUrl, fakeBaseUrl, List.of(fakeBaseUrl), fakeBaseUrl, false, false, false));

        return ApplicationConfig.builder()
                .environments(environments)
                .activeEnvironment(envName)
                .build();
    }

}
