package dev.fitko.fitconnect.sdk.examples;

import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.config.SenderConfig;
import dev.fitko.fitconnect.api.config.SubscriberConfig;
import dev.fitko.fitconnect.api.config.defaults.Environments;
import dev.fitko.fitconnect.api.config.http.HttpConfig;
import dev.fitko.fitconnect.api.config.http.Timeouts;
import dev.fitko.fitconnect.client.bootstrap.ApplicationConfigLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.nio.file.Path;
import java.util.List;

/**
 * Shows different ways loading the config.
 */
public class ApplicationConfigExample {

    private static final Logger LOGGER = LoggerFactory.getLogger(ApplicationConfigExample.class);

    public static void main(String[] args) {

        loadConfigViaConfigLoader();
        constructConfigViaBuilder();
        constructConfigViaBuilderWithCustomHttpTimeouts();
    }

    private static void loadConfigViaConfigLoader() {

        var configPath = Path.of("examples/src/main/resources/config.yml");
        var config = ApplicationConfigLoader.loadConfigFromPath(configPath);
        LOGGER.info("Loaded config {}", config);
    }

    private static void constructConfigViaBuilder() {

        var senderConfig = new SenderConfig("CLIENT_ID", "CLIENT_SECRET");

        var signingKeyPath = "/path/to/signing_key.json";
        var decryptionKeyPaths = List.of("/path/to/decryption_key.json");
        var subscriberConfig = new SubscriberConfig("CLIENT_ID", "CLIENT_SECRET", signingKeyPath, decryptionKeyPaths);

        var config = ApplicationConfig.builder().senderConfig(senderConfig).subscriberConfig(subscriberConfig).activeEnvironment(Environments.TEST.getEnvironmentName()).build();

        LOGGER.info("Loaded config {}", config);
    }

    private static void constructConfigViaBuilderWithCustomHttpTimeouts() {

        var timeouts = Timeouts.builder()
                .readTimeout(60)
                .connectionTimeout(30)
                .build();

        var httpConfig = HttpConfig.builder().timeouts(timeouts).build();
        var config = ApplicationConfig.builder().httpConfig(httpConfig).build();

        LOGGER.info("Loaded config {}", config);
    }
}
