package dev.fitko.fitconnect.sdk.examples;

import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.domain.model.submission.SubmissionForPickup;
import dev.fitko.fitconnect.api.domain.subscriber.ReceivedSubmission;
import dev.fitko.fitconnect.client.SubscriberClient;
import dev.fitko.fitconnect.client.bootstrap.ApplicationConfigLoader;
import dev.fitko.fitconnect.client.bootstrap.ClientFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.nio.file.Path;
import java.util.List;
import java.util.Set;
import java.util.UUID;
import java.util.stream.Collectors;

public class SubscriberExample {

    private static final Logger LOGGER = LoggerFactory.getLogger(SubscriberExample.class);

    /**
     * Fill out config.yml in /resources and provide a DESTINATION_ID that matches the configuration (serviceType, data schema, etc.)
     */
    public static void main(String[] args) {

        final ApplicationConfig config = ApplicationConfigLoader.loadConfigFromPath(Path.of("examples/src/main/resources/config.yml"));

        final SubscriberClient subscriberClient = ClientFactory.createSubscriberClient(config);

        // list all available submissions that are ready for pick-up for the destination
        final Set<SubmissionForPickup> availableSubmissions = subscriberClient.getAvailableSubmissionsForDestination(UUID.fromString("YOUR_DESTINATION_ID"));

        // load the actual data for all available submissions
        final List<ReceivedSubmission> receivedSubmissions = availableSubmissions.stream().map(subscriberClient::requestSubmission).collect(Collectors.toList());

        // access data
        receivedSubmissions.forEach(receivedSubmission -> {
            LOGGER.info("Received Submission {}", receivedSubmission);
            final String data = receivedSubmission.getDataAsString();
            // validate the received data ....
            receivedSubmission.acceptSubmission();
        });
    }
}
